@@ -89,6 +89,7 @@ pub struct ColumnInfo {
     pub align: ConfigColumnAlign,
     pub max_width: Option<usize>,
     pub min_width: Option<usize>,
+    pub visible: bool,
 }
 
 // ---------------------------------------------------------------------------------------------------------------------
@@ -507,6 +508,10 @@ pub struct ConfigDisplay {
     #[serde(default = "default_true")]
     pub show_thread_in_tree: bool,
     #[serde(default = "default_true")]
+    pub show_parent_in_tree: bool,
+    #[serde(default = "default_true")]
+    pub show_children_in_tree: bool,
+    #[serde(default = "default_true")]
     pub cut_to_terminal: bool,
     #[serde(default = "default_false")]
     pub cut_to_pager: bool,
@@ -534,6 +539,8 @@ impl Default for ConfigDisplay {
             show_self: false,
             show_thread: false,
             show_thread_in_tree: true,
+            show_parent_in_tree: true,
+            show_children_in_tree: true,
             cut_to_terminal: true,
             cut_to_pager: false,
             cut_to_pipe: false,
